@@ -31,12 +31,6 @@ from dwave.system.warnings import WarningAction
 from dwave.inspector import storage
 from dwave.inspector.utils import itemsgetter
 
-try:
-    from dimod.core.bqm import BQMView
-except ImportError:
-    # dimod < 0.9
-    from dimod.views.bqm import BQMView
-
 try:
     import dimod.core.bqm
     BQM_CLASSES = (dimod.BinaryQuadraticModel, dimod.core.bqm.BQM)
@@ -54,7 +48,7 @@ __all__ = [
 
 logger = logging.getLogger(__name__)
 
-SUPPORTED_SOLVER_TOPOLOGY_TYPES = {'chimera', 'pegasus'}
+SUPPORTED_SOLVER_TOPOLOGY_TYPES = {'chimera', 'pegasus', 'zephyr'}
 
 
 def enable_data_capture():
@@ -373,10 +367,11 @@ def from_qmi_response(problem, response, embedding_context=None, warnings=None,
     except:
         linear, quadratic = reformat_qubo_as_ising(problem)
 
-    # make sure lin/quad are not dimod views (that handle directed edges)
-    if isinstance(linear, BQMView):
+    # make sure lin/quad are not something like dimod views (that handle
+    # directed edges, and effectively duplicate biases of symmetric couplings)
+    if not isinstance(linear, dict):
         linear = dict(linear)
-    if isinstance(quadratic, BQMView):
+    if not isinstance(quadratic, dict):
         quadratic = dict(quadratic)
 
     solver = response.solver
